import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';

const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');

// dollors 
const numberFormat = number =>
  	(Math.abs(Number(number))) + " $" ;


const render = data => {
  const pieData = pie().sort(null).value(d=>d.Global_Sales)(data);
  const colors = scaleOrdinal(schemeCategory10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(200)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.Global_Sales))
  	.on("mouseover", d => console.log(d.data.Global_Sales));
  //piechart is created 
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  // list of each Genre as labels and its styles

  legend.append("rect").attr("width",22).attr("height",25)
  	.attr("fill", d => colors(d.data.Global_Sales));
  legend.append("text")
  	.attr("x", 28)
  	.attr("y", 18)
  	.attr("class","legend_text")
  	.text(d => d.data.Genre);
  legend.append("text")
  	.attr("x", 260)
  	.attr("y", 20)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.Global_Sales));
}

// url of my data giest

const csvUrl =
 "https://gist.githubusercontent.com/mkowthavarapu/ca0ab0c145719783b4844d32a8460bf6/raw/c8cad8f0b57ef4e98583cac0d755d0003e93aacd/vgsales.csv"


//Load the data and display Global Sales of video games 
csv(csvUrl).then(csvData => {
    csvData.sort((data1, data2) => data2.Global_Sales-data1.Global_Sales);
    if (csvData) {
      render(csvData.slice(0, 10));
    }
});